package com.mdd.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Assert;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mdd.admin.service.ISystemAuthPostService;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.system.SystemPostCreateValidate;
import com.mdd.admin.validate.system.SystemPostSearchValidate;
import com.mdd.admin.validate.system.SystemPostUpdateValidate;
import com.mdd.admin.vo.system.SystemAuthPostVo;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.system.SystemAuthAdmin;
import com.mdd.common.entity.system.SystemAuthPost;
import com.mdd.common.mapper.system.SystemAuthAdminMapper;
import com.mdd.common.mapper.system.SystemAuthPostMapper;
import com.mdd.common.util.TimeUtils;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

@Service
public class SystemAuthPostServiceImpl implements ISystemAuthPostService {
   @Resource
   SystemAuthPostMapper systemAuthPostMapper;
   @Resource
   SystemAuthAdminMapper systemAuthAdminMapper;

   public List<SystemAuthPostVo> all() {
      List<SystemAuthPost> systemAuthPostList = this.systemAuthPostMapper.selectList((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("is_delete", 0)).orderByDesc(Arrays.asList("sort", "id")));
      List<SystemAuthPostVo> adminVoArrayList = new ArrayList();
      Iterator var3 = systemAuthPostList.iterator();

      while(var3.hasNext()) {
         SystemAuthPost systemAuthPost = (SystemAuthPost)var3.next();
         SystemAuthPostVo vo = new SystemAuthPostVo();
         BeanUtils.copyProperties(systemAuthPost, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(systemAuthPost.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(systemAuthPost.getUpdateTime()));
         adminVoArrayList.add(vo);
      }

      return adminVoArrayList;
   }

   public PageResult<SystemAuthPostVo> list(PageValidate pageValidate, SystemPostSearchValidate searchValidate) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      QueryWrapper<SystemAuthPost> queryWrapper = new QueryWrapper();
      ((QueryWrapper)queryWrapper.select(SystemAuthPost.class, (info) -> {
         return !info.getColumn().equals("is_delete") && !info.getColumn().equals("delete_time");
      }).eq("is_delete", 0)).orderByDesc(Arrays.asList("sort", "id"));
      this.systemAuthPostMapper.setSearch(queryWrapper, searchValidate, new String[]{"like:code:str", "like:name:str", "=:isStop@is_stop:int"});
      IPage<SystemAuthPost> iPage = this.systemAuthPostMapper.selectPage(new Page((long)page, (long)limit), queryWrapper);
      List<SystemAuthPostVo> list = new ArrayList();
      Iterator var8 = iPage.getRecords().iterator();

      while(var8.hasNext()) {
         SystemAuthPost systemAuthPost = (SystemAuthPost)var8.next();
         SystemAuthPostVo vo = new SystemAuthPostVo();
         BeanUtils.copyProperties(systemAuthPost, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(systemAuthPost.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(systemAuthPost.getUpdateTime()));
         list.add(vo);
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public SystemAuthPostVo detail(Integer id) {
      SystemAuthPost systemAuthPost = (SystemAuthPost)this.systemAuthPostMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(SystemAuthPost.class, (info) -> {
         return !info.getColumn().equals("is_delete") && !info.getColumn().equals("delete_time");
      }).eq("id", id)).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(systemAuthPost, "岗位不存在", new Object[0]);
      SystemAuthPostVo vo = new SystemAuthPostVo();
      BeanUtils.copyProperties(systemAuthPost, vo);
      vo.setCreateTime(TimeUtils.timestampToDate(systemAuthPost.getCreateTime()));
      vo.setUpdateTime(TimeUtils.timestampToDate(systemAuthPost.getUpdateTime()));
      return vo;
   }

   public void add(SystemPostCreateValidate createValidate) {
      Assert.isNull(this.systemAuthPostMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id,code,name"}).nested((wq) -> {
         QueryWrapper var10000 = (QueryWrapper)((QueryWrapper)((QueryWrapper)wq.eq("code", createValidate.getCode())).or()).eq("name", createValidate.getName());
      })).eq("is_delete", 0)).last("limit 1")), "该岗位已存在", new Object[0]);
      SystemAuthPost model = new SystemAuthPost();
      model.setCode(createValidate.getCode());
      model.setName(createValidate.getName());
      model.setSort(createValidate.getSort());
      model.setRemarks(createValidate.getRemarks());
      model.setIsStop(createValidate.getIsStop());
      model.setCreateTime(System.currentTimeMillis() / 1000L);
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.systemAuthPostMapper.insert(model);
   }

   public void edit(SystemPostUpdateValidate updateValidate) {
      SystemAuthPost model = (SystemAuthPost)this.systemAuthPostMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(SystemAuthPost.class, (info) -> {
         return !info.getColumn().equals("is_delete") && !info.getColumn().equals("delete_time");
      }).eq("id", updateValidate.getId())).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(model, "岗位不存在", new Object[0]);
      Assert.isNull(this.systemAuthPostMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id,code,name"}).ne("id", updateValidate.getId())).nested((wq) -> {
         QueryWrapper var10000 = (QueryWrapper)((QueryWrapper)((QueryWrapper)wq.eq("code", updateValidate.getCode())).or()).eq("name", updateValidate.getName());
      })).eq("is_delete", 0)).last("limit 1")), "该岗位已存在", new Object[0]);
      model.setCode(updateValidate.getCode());
      model.setName(updateValidate.getName());
      model.setSort(updateValidate.getSort());
      model.setRemarks(updateValidate.getRemarks());
      model.setIsStop(updateValidate.getIsStop());
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.systemAuthPostMapper.updateById(model);
   }

   public void del(Integer id) {
      SystemAuthPost model = (SystemAuthPost)this.systemAuthPostMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id,code,name"}).eq("id", id)).eq("is_delete", 0)).last("limit 1"));
      Assert.notNull(model, "岗位不存在", new Object[0]);
      SystemAuthAdmin systemAuthAdmin = (SystemAuthAdmin)this.systemAuthAdminMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id,nickname"}).eq("post_id", id)).eq("is_delete", 0)).last("limit 1"));
      Assert.isNull(systemAuthAdmin, "该岗位已被管理员使用,请先移除", new Object[0]);
      model.setIsDelete(1);
      model.setDeleteTime(System.currentTimeMillis() / 1000L);
      this.systemAuthPostMapper.updateById(model);
   }
}
